//
// GCALDaemon is an OS-independent Java program that offers two-way
// synchronization between Google Calendar and various iCalalendar (RFC 2445)
// compatible calendar applications (Sunbird, Rainlendar, iCal, Lightning, etc).
//
// http://gcaldaemon.sourceforge.net
//
package org.gcaldaemon.standalone;

import org.gcaldaemon.core.Configurator;

/**
 * GCALDAEMON STARTER (standalone application)
 * 
 * Created: Jan 03, 2007 12:50:56 PM
 * 
 * @author Andras Berkes
 */
public final class Main extends Thread {

	// --- GLOBAL CONFIGURATOR OF GCALDAEMON ---

	private static Configurator configurator;

	// --- APPLICATION STARTER ---

	public static final void main(String[] args) {

		// Init program
		Runtime.getRuntime().addShutdownHook(new Main());
		try {
			String configPath = null;
			byte runMode = Configurator.MODE_DAEMON;
			if (args != null && args.length > 0) {
				configPath = args[0];
				if (args.length > 1) {
					String arg = args[1]; 
					if (arg.equals("ondemand") || arg.equals("runonce")) {
						runMode = Configurator.MODE_RUNONCE;
					}
					if (arg.equals("configeditor")) {
						runMode = Configurator.MODE_CONFIGEDITOR;
					}
				}
			}
			configurator = new Configurator(configPath, runMode);
		} catch (Exception fatalError) {
			try {
				Thread.sleep(1000);
			} catch (Exception ignored) {
			}
			System.err.println("FATAL | Service terminated!");
			fatalError.printStackTrace();
		}
	}

	public final void run() {
		try {
			if (configurator != null) {
				configurator.interrupt();
				configurator = null;
			}
		} catch (Throwable ignored) {
		}
	}

}
